==> torchjs-4.0.0.tgz: package/README.md <==
# Torch

[![NPM version][npm-image]][npm-url]
[![build status][travis-image]][travis-url]
[![Test coverage][coveralls-image]][coveralls-url]
[![npm download][download-image]][download-url]
[![babel version][babel-image]][babel-url]
[![electron version][electron-image]][electron-url]

[npm-image]: https://img.shields.io/npm/v/torchjs.svg?style=flat-square
[npm-url]: https://npmjs.org/package/torchjs
[travis-image]: https://img.shields.io/travis/macacajs/torchjs.svg?style=flat-square
[travis-url]: https://travis-ci.org/macacajs/torchjs
[coveralls-image]: https://img.shields.io/coveralls/macacajs/torchjs.svg?style=flat-square
[coveralls-url]: https://coveralls.io/r/macacajs/torchjs?branch=master
[download-image]: https://img.shields.io/npm/dm/torchjs.svg?style=flat-square
[download-url]: https://npmjs.org/package/torchjs
[babel-image]: https://img.shields.io/badge/babel-7-green.svg?style=flat-square
[babel-url]: https://github.com/babel/babel
[electron-image]: https://img.shields.io/badge/electron-11-green.svg?style=flat-square
[electron-url]: https://electronjs.org/

---

Test framework to light up the world.

<!-- GITCONTRIBUTOR_START -->

## Contributors

|[<img src="https://avatars1.githubusercontent.com/u/1011681?v=4" width="100px;"/><br/><sub><b>xudafeng</b></sub>](https://github.com/xudafeng)<br/>|[<img src="https://avatars1.githubusercontent.com/u/1655789?v=4" width="100px;"/><br/><sub><b>leungwensen</b></sub>](https://github.com/leungwensen)<br/>|[<img src="https://avatars1.githubusercontent.com/u/11460601?v=4" width="100px;"/><br/><sub><b>zivyangll</b></sub>](https://github.com/zivyangll)<br/>|[<img src="https://avatars3.githubusercontent.com/u/1209810?v=4" width="100px;"/><br/><sub><b>paradite</b></sub>](https://github.com/paradite)<br/>|[<img src="https://avatars3.githubusercontent.com/u/356347?v=4" width="100px;"/><br/><sub><b>liangjun-jiang</b></sub>](https://github.com/liangjun-jiang)<br/>|
| :---: | :---: | :---: | :---: | :---: |


This project follows the git-contributor [spec](https://github.com/xudafeng/git-contributor), auto updated at `Mon Jul 27 2020 13:30:12 GMT+0800`.

<!-- GITCONTRIBUTOR_END -->

## Installation

```bash
$ npm install torchjs -g
```

For more help, please visite: [macacajs.github.io/torchjs](https://macacajs.github.io/torchjs)

## Sample

[gif demo](http://wx4.sinaimg.cn/large/6d308bd9gy1fiw8er0a5eg20zc0k0he0.gif)

- [G2: The Grammar of Graphics in JavaScript](//github.com/antvis/g2)

## License

The MIT License (MIT)

==> torchjs-13.0.0.tgz: package/README.md <==
# Torch

[![NPM version][npm-image]][npm-url]
[![build status][travis-image]][travis-url]
[![Test coverage][coveralls-image]][coveralls-url]
[![npm download][download-image]][download-url]
[![babel version][babel-image]][babel-url]
[![electron version][electron-image]][electron-url]

[npm-image]: https://img.shields.io/npm/v/torchjs.svg
[npm-url]: https://npmjs.org/package/torchjs
[travis-image]: https://img.shields.io/travis/macacajs/torchjs.svg
[travis-url]: https://travis-ci.org/macacajs/torchjs
[coveralls-image]: https://img.shields.io/coveralls/macacajs/torchjs.svg
[coveralls-url]: https://coveralls.io/r/macacajs/torchjs?branch=master
[download-image]: https://img.shields.io/npm/dm/torchjs.svg
[download-url]: https://npmjs.org/package/torchjs
[babel-image]: https://img.shields.io/badge/babel-7-green.svg
[babel-url]: https://github.com/babel/babel
[electron-image]: https://img.shields.io/badge/electron-11-green.svg
[electron-url]: https://electronjs.org/

---

Test framework to light up the world.

<!-- GITCONTRIBUTOR_START -->

## Contributors

|[<img src="https://avatars1.githubusercontent.com/u/1011681?v=4" width="100px;"/><br/><sub><b>xudafeng</b></sub>](https://github.com/xudafeng)<br/>|[<img src="https://avatars1.githubusercontent.com/u/1655789?v=4" width="100px;"/><br/><sub><b>leungwensen</b></sub>](https://github.com/leungwensen)<br/>|[<img src="https://avatars1.githubusercontent.com/u/11460601?v=4" width="100px;"/><br/><sub><b>zivyangll</b></sub>](https://github.com/zivyangll)<br/>|[<img src="https://avatars3.githubusercontent.com/u/1209810?v=4" width="100px;"/><br/><sub><b>paradite</b></sub>](https://github.com/paradite)<br/>|[<img src="https://avatars3.githubusercontent.com/u/356347?v=4" width="100px;"/><br/><sub><b>liangjun-jiang</b></sub>](https://github.com/liangjun-jiang)<br/>|
| :---: | :---: | :---: | :---: | :---: |


This project follows the git-contributor [spec](https://github.com/xudafeng/git-contributor), auto updated at `Mon Jul 27 2020 13:30:12 GMT+0800`.

<!-- GITCONTRIBUTOR_END -->

## Installation

```bash
$ npm install torchjs -g
```

For more help, please visite: [macacajs.github.io/torchjs](https://macacajs.github.io/torchjs)

## Sample

[gif demo](http://wx4.sinaimg.cn/large/6d308bd9gy1fiw8er0a5eg20zc0k0he0.gif)

- [G2: The Grammar of Graphics in JavaScript](//github.com/antvis/g2)

## License

The MIT License (MIT)
